@@ -40,7 +40,7 @@ From highest to lowest priority configuration directories, the possible variants
     gcc.release
 """.format(
             tempdir,
-            os.path.join(tempdir, "ct", "ct.conf.d"),
+            os.path.join(tempdir, "ct.conf.d"),
             os.path.join(uth.cakedir(), "ct", "ct.conf.d"),
         )
 
